
[![codecov](https://codecov.io/github/tzoght/mltz-base/branch/main/graph/badge.svg?token=UB03POGOUB)](https://codecov.io/github/tzoght/mltz-base)
[![ci-cd](https://github.com/tzoght/mltz-base/actions/workflows/ci-cd.yml/badge.svg?branch=main)](https://github.com/tzoght/mltz-base/actions/workflows/ci-cd.yml) [![Documentation Status](https://readthedocs.org/projects/mltz-base/badge/?version=latest)](https://mltz-base.readthedocs.io/en/latest/?badge=latest)

# mltz_base

Base Package for ML related dev

## Installation

```bash
$ pip install mltz_base
```
from  [Pypi repo](https://pypi.org/manage/project/mltz-base/releases/)

## Usage

- Coming soon

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`mltz_base` was created by Tony Zoght. It is licensed under the terms of the MIT license.

## Credits

`mltz_base` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).


## Code Coverage
* [CodeCov](https://app.codecov.io/github/tzoght/mltz-base) 